@@ -42,17 +42,19 @@ class Source:
 
     def get_next_pixel(self) -> Optional[Tuple[int,  int, "Color"]]:
         if self.fix and self.fix_queue:
-            return self.fix_queue.pop()
+            return self.fix_queue.pop(0)
         if self.pixel_queue:
-            return self.pixel_queue.pop()
+            return self.pixel_queue.pop(0)
         return None
 
     def update_fix_queue(self, canvas: "Canvas"):
         if not self.fix:
             return
-        self.fix_queue = []
         for x, y, p in self.pixels:
-            if p in self.pixel_queue:
+            v = (x, y, p)
+            if v in self.pixel_queue:
+                continue
+            if v in self.fix_queue:
                 continue
             if canvas[x, y] != p:
                 self.fix_queue.append((x, y, p))
